@@ -22,7 +22,8 @@
  * 
  */
 
-struct mcmcSamples{
+class mcmcSamples{
+  public:
   /*******************
    *for model averaging
    *********************/
@@ -35,4 +36,9 @@ struct mcmcSamples{
   Eigen::MatrixXd log_posterior;
   double BMR;
   bool isExtra;
+  mcmcSamples(){
+    isExtra = true; 
+    map = -1e8; 
+    BMR = 0; 
+  }
 };
